# -*- coding: utf-8 -*-
from setuphelpers import *


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    url = "https://www.libreoffice.org/download/download"
    bin_contains = "LibreOffice_"
    ends_bin_name = "_Linux_x86-64_deb.tar.gz"

    # Getting latest version from official sources
    version = sorted([u.contents[0].strip('/') for u in bs_find_all('https://download.documentfoundation.org/libreoffice/stable/','a','href',proxies=proxies,) if u.contents[0].endswith('/')], key=lambda p: (Version(p)))[-2]
    search_url = "https://download.documentfoundation.org/libreoffice/stable/%s/mac/x86_64/" % version
    for bs_search in bs_find_all(search_url, "a", proxies=proxies):
        if bin_contains in bs_search["href"] and ends_bin_name in bs_search["href"]:
            latest_bin = bs_search.string
            download_url = search_url + latest_bin
            break

    # Downloading latest binaries
    download_url = "https://download.documentfoundation.org/libreoffice/stable/%s/deb/x86_64/LibreOffice_%s_Linux_x86-64_deb.tar.gz" % (
        version,
        version,
    )
    latest_bin = "LibreOffice_%s_Linux_x86-64_deb.tar.gz" % version
    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL is: %s" % download_url)
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating or not update-package-sources
    return package_updated
